import { getQueryKey } from "@trpc/react-query";
import { api, RouterOutputs } from "../trpc"; // Adjust path as necessary
import { useQueryClient, UseMutationResult } from "@tanstack/react-query";
import { ObjectType } from "@nice/common";
import { CrudOperation, emitDataChange } from "../../event";

interface SportOperation {
    createSportProject: UseMutationResult<RouterOutputs["sportProject"]["create"], Error, Parameters<typeof api.sportProject.create.useMutation>[0], unknown>;
    createSportStandard: UseMutationResult<RouterOutputs["sportStandard"]["createStandard"], Error, Parameters<typeof api.sportStandard.createStandard.useMutation<RouterOutputs["sportStandard"]["createStandard"]>>[0], unknown>;
}
export function useSport(): SportOperation {
    const queryClient = useQueryClient();
    const queryKey = getQueryKey(api.sportProject);
    const queryKeyStandard = getQueryKey(api.sportStandard.createStandard);

    const createSportProject = api.sportProject.create.useMutation({
        onSuccess: (result) => {
            queryClient.invalidateQueries({ queryKey });
            emitDataChange(ObjectType.SPORT_PROJECT, result, CrudOperation.CREATED);
        },
    });

    const createSportStandard = api.sportStandard.createStandard.useMutation<RouterOutputs["sportStandard"]["createStandard"]>({
        onSuccess: (result) => {
            queryClient.invalidateQueries({ queryKey: queryKeyStandard });
            emitDataChange(ObjectType.SPORT_STANDARD, result, CrudOperation.CREATED);
        },
    });
    return {
        createSportProject: createSportProject as any as UseMutationResult<RouterOutputs["sportProject"]["create"], Error, Parameters<typeof api.sportProject.create.useMutation>[0], unknown>,
        createSportStandard: createSportStandard as any as UseMutationResult<RouterOutputs["sportStandard"]["createStandard"], Error, Parameters<typeof api.sportStandard.createStandard.useMutation<RouterOutputs["sportStandard"]["createStandard"]>>[0], unknown>,
    };
}